
#import "PacManPreferencesBrain.h"
#import "PacManView.h"			// Need to send it the new -setScale: method
#import <stdio.h>
#import <string.h>

#define DEFAULTscale 1

@implementation PacManPreferencesBrain

// Methods for the Preference we add (the screen size "scale", int: 1 or 2)
//  -(int)scale to query, - setScale:(int)newScale to set programmatically,
//  and - scaleChange:sender to change from the panel's controls.
- (int)scale { return scale; }

- setScale:(int)newScale
{ // keep the value in the accepted range
	if ((newScale < 1) || (newScale > 2)) return self;
	scale = newScale;
	return self;
}

- scaleChange:sender
{ // sender must be a Matrix of radio buttons with the tags 1=small, 2=big
	scale = [[sender selectedCell] tag];
	[gameScreen setScale:scale];
	return self;
}

- readDefaults:sender		// get preferences from defaults database
{	// This shows how to add other prefs values beyond what the GameKit
	// normally provides *and* how to override GameKit restrictions on
	// the size of these variables (speedm in this case; GameKit restricts
	// it to the range 0-2, but I want 0-3 for PacMan.)
	int speedTemp = getIntPreference("GameSpeed", 0, 3, 1);
	scale = getIntPreference("GameSpeed", 1, 2, DEFAULTscale); // a new pref
	[super readDefaults:sender]; // get the GameKit versions
	speed = speedTemp;	// override the GameKit restrictions
    return self;
}

- writeDefaults:sender		// save preferences in defaults database
{
	[super writeDefaults:sender];
	// don't need to override speed here, just add the new pref.
	putIntPreference("Scale",	scale);
    return self;
}

- revert:sender	// return to default values
{
	[super revert:sender];
	scale = DEFAULTscale;	// this is the default value of the scale
	return [self preferences:self]; // update the panel
}

- refresh
{
	[super refresh]; // puts current prefs values into the panel
    [scaleMatrix selectCellWithTag:scale];
	return self;
}

// The next three methods are added to load specific pictures into the
// background...  the pix must be in the app wrapper.  The methods all
// just ask the GameView to load the background image and then display it.

- back1:sender { return [gameScreen loadAnImage:"Gradation.eps"]; }
- back2:sender { return [gameScreen loadAnImage:"lush.tiff"]; }
- back3:sender { return [gameScreen loadAnImage:"Sunset.tiff"]; }

@end
